@@ -3,10 +3,12 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
+import uuid
 from typing import Optional
 
 import comm.base_comm
 import traitlets.config
+from traitlets import Bool, Bytes, Instance, Unicode, default
 
 from ipykernel.jsonutil import json_clean
 from ipykernel.kernelbase import Kernel
@@ -40,14 +42,42 @@ class BaseComm(comm.base_comm.BaseComm):
 
 
 # but for backwards compatibility, we need to inherit from LoggingConfigurable
-class Comm(traitlets.config.LoggingConfigurable, BaseComm):
+class Comm(BaseComm, traitlets.config.LoggingConfigurable):
     """Class for communicating between a Frontend and a Kernel"""
 
-    def __init__(self, *args, **kwargs):
-        self.kernel = None
-        # Comm takes positional arguments, LoggingConfigurable does not, so we explicitly forward arguments
+    kernel = Instance("ipykernel.kernelbase.Kernel", allow_none=True)  # type:ignore[assignment]
+    comm_id = Unicode()
+    primary = Bool(True, help="Am I the primary or secondary Comm?")
+
+    target_name = Unicode("comm")
+    target_module = Unicode(
+        None,
+        allow_none=True,
+        help="""requirejs module from
+        which to load comm target.""",
+    )
+
+    topic = Bytes()
+
+    @default("kernel")
+    def _default_kernel(self):
+        if Kernel.initialized():
+            return Kernel.instance()
+
+    @default("comm_id")
+    def _default_comm_id(self):
+        return uuid.uuid4().hex
+
+    def __init__(self, target_name='', data=None, metadata=None, buffers=None, **kwargs):
+        # Handle differing arguments between base classes.
+        kernel = kwargs.pop('kernel', None)
+        if target_name:
+            kwargs['target_name'] = target_name
+        BaseComm.__init__(
+            self, data=data, metadata=metadata, buffers=buffers, **kwargs
+        )  # type:ignore[call-arg]
+        kwargs['kernel'] = kernel
         traitlets.config.LoggingConfigurable.__init__(self, **kwargs)
-        BaseComm.__init__(self, *args, **kwargs)
 
 
 __all__ = ["Comm"]
